@@ -2,7 +2,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 
     SPDX-FileCopyrightText: 2003 Brian Thomas <thomas@mail630.gsfc.nasa.gov>
-    SPDX-FileCopyrightText: 2004-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2004-2021 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 // own header
@@ -385,7 +385,7 @@ void CPPCodeGenerator::checkRemoveUMLObject(UMLObject * obj)
  * Add C++ primitives as datatypes.
  * @return a string list of C++ datatypes
  */
-QStringList CPPCodeGenerator::defaultDatatypes()
+QStringList CPPCodeGenerator::defaultDatatypes() const
 {
     return Codegen_Utils::cppDatatypes();
 }
