@@ -2,7 +2,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 
     SPDX-FileCopyrightText: 2003 Brian Thomas <thomas@mail630.gsfc.nasa.gov>
-    SPDX-FileCopyrightText: 2004-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2004-2021 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 // own header
@@ -249,7 +249,7 @@ void JavaANTCodeDocument::updateContent()
 }
 
 // We overwritten by Java language implementation to get lowercase path
-QString JavaANTCodeDocument::getPath ()
+QString JavaANTCodeDocument::getPath () const
 {
     QString path = getPackage();
 
