@@ -1,14 +1,10 @@
-/***************************************************************************
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   copyright (C) 2002      Heiko Nardmann  <h.nardmann@secunet.de>       *
- *                           Thorsten Kunz   <tk AT bytecrash DOT net>     *
- *   copyright (C) 2003-2014                                               *
- *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
- ***************************************************************************/
+/*
+    SPDX-License-Identifier: GPL-2.0-or-later
+
+    SPDX-FileCopyrightText: 2002 Heiko Nardmann <h.nardmann@secunet.de>
+    SPDX-FileCopyrightText: 2004 Thorsten Kunz <tk AT bytecrash DOT net>
+    SPDX-FileCopyrightText: 2003-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+*/
 
 #include "php5writer.h"
 
@@ -3019,7 +3015,7 @@ void Php5Writer::writeClass(UMLClassifier *c)
     //Start generating the code!!
     /////////////////////////////
 
-    //try to find a heading file (license, coments, etc)
+    //try to find a heading file (license, comments, etc)
     QString str;
     str = getHeadingFile(QLatin1String(".php"));
     if (!str.isEmpty()) {
@@ -3041,7 +3037,7 @@ void Php5Writer::writeClass(UMLClassifier *c)
     }
     php << m_endl;
 
-    //Write class Documentation if there is somthing or if force option
+    //Write class Documentation if there is something or if force option
     if (forceDoc() || !c->doc().isEmpty()) {
         php << m_endl << "/**" << m_endl;
         php << " * class " << classname << m_endl;
@@ -3094,7 +3090,7 @@ void Php5Writer::writeClass(UMLClassifier *c)
             //maybe we should parse the string here and take multiplicity into account to decide
             //which container to use.
             UMLObject *o = a->getObject(Uml::RoleType::A);
-            if (o == NULL) {
+            if (o == 0) {
                 uError() << "aggregation role A object is NULL" << endl;
                 continue;
             }
@@ -3112,7 +3108,7 @@ void Php5Writer::writeClass(UMLClassifier *c)
         foreach (UMLAssociation* a, compositions) {
             // see comment on Aggregation about multiplicity...
             UMLObject *o = a->getObject(Uml::RoleType::A);
-            if (o == NULL) {
+            if (o == 0) {
                 uError() << "composition role A object is NULL";
                 continue;
             }
@@ -3452,5 +3448,4 @@ QStringList Php5Writer::reservedKeywords() const
 }
 
 
-#include "php5writer.moc"
 
